@@ -20,7 +20,7 @@
 #ifndef CONTENTINDEXTEXT_H
 #define CONTENTINDEXTEXT_H
 
-#include <QtCore/QObject>
+#include <QObject>
 
 class ContentIndexTest : public QObject
 {
@@ -29,6 +29,7 @@ private Q_SLOTS:
     void testToString();
     void testFromString();
     void testContent();
+    void testNavigation();
 };
 
 #endif
